@@ -21,6 +21,7 @@ from __future__ import division
 from __future__ import unicode_literals
 import datetime
 import json
+import codecs
 import six
 
 class Fail(BaseException):
@@ -152,7 +153,8 @@ def get_json(f, compression=None):
             raise Fail(500, "{} compression is not supported".format(compression))
     else:
         try:
-            return json.load(f)
+            reader = codecs.getreader("utf-8")
+            return json.load(reader(f))
         except (ValueError, UnicodeDecodeError):
             raise Fail(400, "invalid JSON data")
 
